@@ -1,4 +1,4 @@
-/* $Id: xfburn-device-box.c 6350 2008-12-21 02:25:44Z squisher $ */
+/* $Id: xfburn-device-box.c 6735 2009-02-22 03:26:03Z squisher $ */
 /*
  * Copyright (c) 2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -130,10 +130,10 @@ static GtkVBoxClass *parent_class = NULL;
 /*************************/
 static guint signals[LAST_SIGNAL];
 
-GtkType
+GType
 xfburn_device_box_get_type (void)
 {
-  static GtkType device_box_type = 0;
+  static GType device_box_type = 0;
 
   if (!device_box_type)
     {
