@@ -1,4 +1,4 @@
-/* $Id: xfburn-error.h 5932 2008-11-03 06:55:02Z squisher $ */
+/* $Id: xfburn-error.h 6210 2008-11-26 23:27:19Z squisher $ */
 /*
  * Copyright (c) 2008 David Mohr <david@mcbf.net>
  *
@@ -41,6 +41,8 @@ typedef enum
   XFBURN_ERROR_GST_TIMEOUT,
   XFBURN_ERROR_PIPE,
   XFBURN_ERROR_GST_NO_AUDIO,
+  XFBURN_ERROR_TOO_MANY_AUDIO_TRACKS,
+  XFBURN_ERROR_MISSING_PLUGIN,
 } XfburnError;
 
 #define XFBURN_ERROR xfburn_error_quark ()
